## Credits

This page aims to detail who is directly responsible for what, and where appropriate
indirectly.

### Directly

**Michael Sparks** : <sparks.m@gmail.com>, [blog](http://www.sparkslabs.com/michael/), [twitter](http://twitter.com/sparks_rd), [Linked in](https://www.linkedin.com/pub/michael-sparks/0/1b9/a93)

* Implementation of Lexer, parser, code generation, AST, transforms, code generation, packaging etc
* Language spec
* Website design and implementation


**Your name here**: contact details

* What you've done/helped with


### Projects used by Pyxie (etc)

Listing key projects used here is a way of saying thank you :-)

**David Beazley** : for [PLY](http://www.dabeaz.com/ply/ply.html) - the python lex/yacc implementation used.

